package com.ruoyi.depart.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.depart.mapper.SysDepartMapper;
import com.ruoyi.depart.domain.SysDepart;
import com.ruoyi.depart.service.ISysDepartService;

/**
 * 组织机构Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-14
 */
@Service
public class SysDepartServiceImpl implements ISysDepartService 
{
    @Autowired
    private SysDepartMapper sysDepartMapper;

    /**
     * 查询组织机构
     * 
     * @param id 组织机构主键
     * @return 组织机构
     */
    @Override
    public SysDepart selectSysDepartById(String id)
    {
        return sysDepartMapper.selectSysDepartById(id);
    }

    /**
     * 查询组织机构列表
     * 
     * @param sysDepart 组织机构
     * @return 组织机构
     */
    @Override
    public List<SysDepart> selectSysDepartList(SysDepart sysDepart)
    {
        return sysDepartMapper.selectSysDepartList(sysDepart);
    }

    /**
     * 新增组织机构
     * 
     * @param sysDepart 组织机构
     * @return 结果
     */
    @Override
    public int insertSysDepart(SysDepart sysDepart)
    {
        sysDepart.setCreateTime(DateUtils.getNowDate());
        return sysDepartMapper.insertSysDepart(sysDepart);
    }

    /**
     * 修改组织机构
     * 
     * @param sysDepart 组织机构
     * @return 结果
     */
    @Override
    public int updateSysDepart(SysDepart sysDepart)
    {
        sysDepart.setUpdateTime(DateUtils.getNowDate());
        return sysDepartMapper.updateSysDepart(sysDepart);
    }

    /**
     * 批量删除组织机构
     * 
     * @param ids 需要删除的组织机构主键
     * @return 结果
     */
    @Override
    public int deleteSysDepartByIds(String[] ids)
    {
        return sysDepartMapper.deleteSysDepartByIds(ids);
    }

    /**
     * 删除组织机构信息
     * 
     * @param id 组织机构主键
     * @return 结果
     */
    @Override
    public int deleteSysDepartById(String id)
    {
        return sysDepartMapper.deleteSysDepartById(id);
    }

    /**
     * 根据部门名称查询部门信息
     *
     * @param userdept 部门名称
     * @return 结果
     */
    @Override
    public SysDepart selectDeptTypeByDeptName(String userdept) {
        return sysDepartMapper.selectDeptTypeByDeptName(userdept);
    }
}
